@@ -9,12 +9,13 @@ from functools import lru_cache
 from os.path import abspath, dirname
 # import awswrangler as wr
 from typing import Dict
-from boto3.session import Session
-from packaging import version
 
 import findspark
 import tomlkit
 from black import FileMode, format_str
+from boto3.session import Session
+from packaging import version
+
 
 REQUIRED_PARAM = ["s3-staging-dir", "cluster-name", "stage", "region"]
 DEFAULT_TOML_PATH = "./pyproject.toml"
@@ -33,14 +34,14 @@ DEFAULT_CONFIG_TEMPLATE = {
 # spark_version
 
 INPUT_TYPES = {
-        "cluster-name": str,
-        "s3-staging-dir": str ,
-        "stage": str,
-        "date-time": str ,
-        "s3-patch-dir": str,
-        "spark-version": str ,
+    "cluster-name": str,
+    "s3-staging-dir": str,
+    "stage": str,
+    "date-time": str,
+    "s3-patch-dir": str,
+    "spark-version": str,
 }
-    
+
 
 DEFAULT_DEPENDENCIES = dict(
     Cython="0.29.24",
@@ -145,55 +146,82 @@ def create_git_ignore():
 
 @lru_cache()
 def get_avalible_s3_regions():
+    """ """
     session = Session()
-    s3_regions = session.get_available_regions('s3')
+    s3_regions = session.get_available_regions("s3")
     return s3_regions
 
 
-def validate_input(key,value):
-    
+def validate_input(key, value):
+    """
+
+    Args:
+      key:
+      value:
+
+    Returns:
+
+    """
+
     if key in INPUT_TYPES:
         if type(value) != INPUT_TYPES[key]:
             raise ValueError(f"'{key}' must be a {INPUT_TYPES[key]}")
-    
-    if key == "region" :
+
+    if key == "region":
         aws_regions = get_avalible_s3_regions()
         if (value not in aws_regions) or (type(value) != str):
             raise ValueError(f"'{key}' must be one of {aws_regions}.")
-    
+
     s3_client_ = ["s3://", "s3n://", "s3a://"]
     if key == "s3-staging-dir":
-        if not any([ value.startswith(p) for p in s3_client_ ]):
-            raise ValueError(f"'{key}' must be a valid s3 path startign with {s3_client_}.")
-    
-    if value is None or (type(value) == str and value.strip() in '') :
-        raise ValueError(f"'{key}' is not a valid value of {key}.")
-    
-    if key == 'spark-version':
-        if type(version.parse(value)) == version.LegacyVersion :
-            print("Warning: Is the spark version '{value}' specified valid? ")
-    
-    if key == 'stage':
-        if value not in ['dev','prod','stage','qa','test']:
-            print("Warning: 'stage' is meant to be one of ['dev','qa','prod']")
-    
-    
+        if not any(value.startswith(p) for p in s3_client_):
+            raise ValueError(
+                f"'{key}' must be a valid s3 path startign with {s3_client_}.",
+            )
 
-def format_input( key, value):
-    """"""
+    if value is None or (type(value) == str and value.strip() in ""):
+        raise ValueError(f"'{key}' is not a valid value of {key}.")
+
+    if key == "spark-version":
+        if type(version.parse(value)) == version.LegacyVersion:
+            print("Warning: Is the spark version '{value}' specified valid? ")
+
+    if key == "stage":
+        if value not in ["dev", "prod", "stage", "qa", "test"]:
+            print("Warning: 'stage' is meant to be one of ['dev','qa','prod']")
+
+
+def format_input(key, value):
+    """
+
+    Args:
+      key:
+      value:
+
+    Returns:
+
+    """
     if key in INPUT_TYPES:
-        value= INPUT_TYPES[key](value)
-    
-    if key == 'stage':
+        value = INPUT_TYPES[key](value)
+
+    if key == "stage":
         value = value.lower()
-    
+
     if type(value) == str:
         value = value.strip()
-    
+
     return value
 
 
 def get_default_value(key):
+    """
+
+    Args:
+      key:
+
+    Returns:
+
+    """
     return DEFAULT_CONFIG_TEMPLATE.get(key, "")
 
 
@@ -209,22 +237,22 @@ def get_config_attr(key, toml_path=DEFAULT_TOML_PATH):
     Returns:
 
     """
-    
+
     if not _pyproject_toml_exists(toml_path):
         cprint(f"No '{toml_path}' found.", "WARNING")
-    
+
     conf = load_config()
-    if not (conf.get(key) in [None,'','\n']) :
+    if not (conf.get(key) in [None, "", "\n"]):
         return conf[key]
-    
-    if len(conf) > 0 :
+
+    if len(conf) > 0:
         cprint(f"No valid '{key}' found in config.", "WARNING")
-    
+
     default_value = get_default_value(key)
     value = cinput(f"Select {key}", default_value)
     value = format_input(key, value)
     validate_input(key, value)
-    
+
     return value
 
 
@@ -248,6 +276,10 @@ def get_project_attributes(keys: list):
 
     Args:
       keys: list
+      keys: list:
+      keys: list:
+      keys: list:
+      keys: list:
 
     Returns:
 
@@ -324,6 +356,10 @@ def get_cluster_name(cluster_name: str = "default"):
 
     Args:
       cluster_name: str:  (Default value = 'default')
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
+      cluster_name: str:  (Default value = "default")
 
     Returns:
 
@@ -375,6 +411,10 @@ def get_project_type(toml_path: str = DEFAULT_TOML_PATH):
 
     Args:
       toml_path: str:  (Default value = DEFAULT_TOML_PATH)
+      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
+      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
+      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
+      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
 
@@ -390,6 +430,10 @@ def _pyproject_toml_exists(pyproj_path: str = DEFAULT_TOML_PATH):
 
     Args:
       pyproj_path: str: (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
 
@@ -402,6 +446,10 @@ def _get_pyproject_toml(pyproj_path: str = DEFAULT_TOML_PATH) -> Dict[str, str]:
 
     Args:
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
       dict: Project toml param.
@@ -424,7 +472,15 @@ def _write_pyproject_toml(file_contents: dict, pyproj_path: str = DEFAULT_TOML_P
     Args:
       file_contents: dict:
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-    
+      file_contents: dict:
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      file_contents: dict:
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      file_contents: dict:
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+      file_contents: dict:
+      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
+
     Returns:
 
     """
@@ -434,13 +490,13 @@ def _write_pyproject_toml(file_contents: dict, pyproj_path: str = DEFAULT_TOML_P
 
 def load_config():
     """Loads the pyemr config parameters from the project toml file."""
-    
+
     if _pyproject_toml_exists():
         tml = _get_pyproject_toml()
         if "tool" in tml:
             if "pyemr" in tml["tool"]:
                 return tml["tool"]["pyemr"]
-    
+
     return {}
 
 
@@ -514,9 +570,7 @@ def cprint(text, color="OKCYAN"):
     print(color_text(text, color))
 
 
-
-
-def init_pyemr_param( **kwargs ):
+def init_pyemr_param(**kwargs):
     """Append EMR pack parameters to the project toml.
 
     Args:
@@ -525,38 +579,39 @@ def init_pyemr_param( **kwargs ):
       s3_stage_dir:
       stage:
       region:
+      **kwargs:
 
     Returns:
 
     """
-    
+
     # convert kwargs to toml key names
-    kwargs = { k.replace("_",'-'): v for k,v in kwargs.items() }
-    
-    # get pyemr config values 
+    kwargs = {k.replace("_", "-"): v for k, v in kwargs.items()}
+
+    # get pyemr config values
     tml = _get_pyproject_toml()
-    tml['tool'] =tml.get('tool',{})
-    tool_pyemr_ = tml['tool'].get('pyemr',{})
-    
+    tml["tool"] = tml.get("tool", {})
+    tool_pyemr_ = tml["tool"].get("pyemr", {})
+
     for key, default_value in DEFAULT_CONFIG_TEMPLATE.items():
-        if key in kwargs and (kwargs[key] is not None) and (kwargs[key]!=''):
+        if key in kwargs and (kwargs[key] is not None) and (kwargs[key] != ""):
             value = kwargs[key]
             value = format_input(key, value)
             validate_input(key, value)
             tool_pyemr_[key] = value
-            cprint(  f'{key}: ' + color_text(f'{value}', "OKGREEN") )
+            cprint(f"{key}: " + color_text(f"{value}", "OKGREEN"))
         else:
             if key in REQUIRED_PARAM:
                 value = cinput(key, default_value)
             else:
                 value = default_value
-            
+
             value = format_input(key, value)
             validate_input(key, value)
             value = format_input(key, value)
             tool_pyemr_[key] = value
-    
-    tml['tool']['pyemr']  = tool_pyemr_
+
+    tml["tool"]["pyemr"] = tool_pyemr_
     _write_pyproject_toml(tml)
 
 
@@ -565,6 +620,10 @@ def add_dependencies(dependencies: list):
 
     Args:
       dependencies: list: A list of pypi package names.
+      dependencies: list:
+      dependencies: list:
+      dependencies: list:
+      dependencies: list:
 
     Returns:
 
@@ -686,16 +745,23 @@ def init_pyemr(project_name, cluster_name, s3_stage_dir, stage, region):
         ] + dep
         with subprocess.Popen(args) as proc:
             proc.communicate()
-    
+
     # install default dependencies
     add_dependencies(DEFAULT_DEPENDENCIES)
     add_scr_package()
-    init_pyemr_param(cluster_name=cluster_name, s3_staging_dir=s3_stage_dir, stage=stage, region=region)
+    init_pyemr_param(
+        cluster_name=cluster_name,
+        s3_staging_dir=s3_stage_dir,
+        stage=stage,
+        region=region,
+    )
     create_git_ignore()
-    
+
     if not os.path.isfile("pyproject.toml"):
-        raise ValueError("Whoops... something went wrong. 'pyproject.toml' does not exist. Please report this on git. ")
-    
+        raise ValueError(
+            "Whoops... something went wrong. 'pyproject.toml' does not exist. Please report this on git. ",
+        )
+
     # os.system("open pyproject.toml")
 
 
