@@ -6,51 +6,33 @@ from pathlib import Path
 from subprocess import STDOUT, TimeoutExpired, check_output
 
 import docker
+from pkg_resources import get_distribution
 
+from pyemr.utils.config import cinput, cprint, get_config_attr, get_package_dir
 from pyemr.utils.sys import is_port_in_use, pipe_cmd
 
-from .config import cinput, cprint, get_config_attr, get_package_dir
 
+__version__ = get_distribution("pyemr").version
 
 SH_DIR_DOCKER = "/pyemr/files/sh"
-AMAZON_LINUX_DOCKER_TAG = "pyemr/amazonlinux:latest"
+AMAZON_LINUX_DOCKER_TAG = f"pyemr.{__version__}/amazonlinux:latest"
 AMAZON_LINUX_DOCKER_FILE = "files/docker/amazonlinux.spark{spark_version}.Dockerfile"
 
 
 def launch_docker_shell():
     """Launch the docker shell."""
     docker_build(AMAZON_LINUX_DOCKER_FILE, AMAZON_LINUX_DOCKER_TAG)
-
     cwd = os.getcwd()
-    docker_run_sh(cwd, "", it=True)
+    docker_run_sh(cwd, it=True, entry_point="sh")
 
 
 def launch_docker_bash():
     """Launches the docker bash."""
     docker_build(AMAZON_LINUX_DOCKER_FILE, AMAZON_LINUX_DOCKER_TAG)
-
-    docker_run_sh(os.getcwd(), "", it=True, entry_point="bash")
+    docker_run_sh(os.getcwd(), it=True, entry_point="bash")
 
 
-def local_spark_submit(script):
-    """Run the spark submit from inside docker.
-
-    Args:
-      script:
-
-    Returns:
-
-    """
-    docker_build(AMAZON_LINUX_DOCKER_FILE, AMAZON_LINUX_DOCKER_TAG)
-    docker_run_sh(
-        os.getcwd(),
-        f"{SH_DIR_DOCKER}/spark_submit.sh {script}",
-        it=True,
-        p="8889:8889",
-    )
-
-
-def is_docker_build(tag_name):
+def is_docker_built(tag_name):
     """Checks if the docker image is built.
 
     Args:
@@ -79,9 +61,6 @@ def docker_build(
       dockerfile: str:  (Default value = AMAZON_LINUX_DOCKER_FILE)
       dockerfile: str:  (Default value = AMAZON_LINUX_DOCKER_FILE)
       dockerfile: str:  (Default value = AMAZON_LINUX_DOCKER_FILE)
-      dockerfile: str:  (Default value = AMAZON_LINUX_DOCKER_FILE)
-      dockerfile: str:  (Default value = AMAZON_LINUX_DOCKER_FILE)
-      dockerfile: str:  (Default value = AMAZON_LINUX_DOCKER_FILE)
 
     Returns:
 
@@ -97,7 +76,7 @@ def docker_build(
             f"No docker image found for spark {spark_version}. Create a new docker file called '{project_dir}/{dockerfile}'.",
         )
 
-    if is_docker_build(tag_name) == False:
+    if is_docker_built(tag_name) == False:
         cprint(
             f"WARNING:This is the first time you using pyemr or '{dockerfile}'. It might take ~5 minutes.",
         )
@@ -106,38 +85,72 @@ def docker_build(
     pipe_cmd(cmd, cwd=project_dir)
 
 
-def docker_build_run(cmd):
-    """
+def docker_build_run(cmd, entry_point="sh"):
+    """Builds a docker container and runs a sh/bash command insidde it.
 
     Args:
       cmd:
+      entry_point: (Default value = 'sh')
 
     Returns:
 
     """
+
+    if type(cmd) == list:
+        cmd = "; ".join(cmd)
+
     docker_engine_warning()
     docker_build(AMAZON_LINUX_DOCKER_FILE, AMAZON_LINUX_DOCKER_TAG)
     docker_run_sh(
         os.getcwd(),
         cmd,
         it=True,
+        entry_point=entry_point,
     )
 
 
+def stop_pyemr_containers_with_warning(port):
+    """Stops the pyemr containers, warning the user and giving them time to cancel.
+
+    Args:
+      port:
+
+    Returns:
+
+    """
+
+    if is_port_in_use(port):
+        print("\n")
+        cprint(
+            f"Port {port} already in use. Stopping all other pyemr sessions...",
+            "FAIL",
+        )
+        cprint("(otherwise press ^C)", "FAIL")
+        time.sleep(5)
+
+    if is_port_in_use(port):
+        stop_pyemr_containers()
+
+    if is_port_in_use(port):
+        raise ValueError(
+            f"Port {port} is already in use. Do you have pyemr container already running? Try 'docker container list', then 'docker stop'.",
+        )
+
+
 def docker_run_sh(
-    mount_dir,
-    sh_cmd="",
+    mount_dir=os.getcwd(),
+    c="",
     it=False,
     p="8889:8889",
     entry_point="sh",
     tag_name=AMAZON_LINUX_DOCKER_TAG,
 ):
-    """Runs sh from the docker file.
+    """Runs an sh/bash command from using inside an docker container.
 
     Args:
       tag_name: (Default value = AMAZON_LINUX_DOCKER_TAG)
-      mount_dir:
-      sh_cmd: (Default value = '')
+      mount_dir: (Default value = os.getcwd())
+      c: (Default value = '')
       it: (Default value = False)
       p: (Default value = None)
       entry_point: (Default value = 'sh')
@@ -147,26 +160,7 @@ def docker_run_sh(
     """
     if p:
         out_port = int(p.split(":")[-1])
-
-        if is_port_in_use(out_port):
-            print("\n")
-            cprint(
-                f"Port {out_port} already in use. Stopping all other pyemr sessions...",
-                "FAIL",
-            )
-            cprint("(otherwise press ^C)", "FAIL")
-            time.sleep(5)
-
-        if is_port_in_use(out_port):
-            stop_pyemr_containers()
-            # reply = cinput('\t Stop all other pyemr notebooks/containers', 'y' )
-            # if reply in ['y', 'Y','Yes', 'YES' ]:
-            # else:
-
-        if is_port_in_use(out_port):
-            raise ValueError(
-                f"Port {out_port} is already in use. Do you have pyemr container already running? Try 'docker container list', then 'docker stop'.",
-            )
+        stop_pyemr_containers_with_warning(out_port)
 
     home = str(Path.home())
     pwd_mount = f'src="{mount_dir}",target=/app,type=bind'
@@ -178,12 +172,16 @@ def docker_run_sh(
     if p is not None:
         cmd += ["-p", p]
 
-    cmd += [tag_name, entry_point, sh_cmd]
+    cmd += [tag_name, entry_point]
+
+    if c and c.strip() != "":
+        cmd += ["-c", f'"{c}"']
+
     pipe_cmd(cmd)
 
 
 def docker_containers_list():
-    """ """
+    """List all docker containers."""
     client = docker.from_env()
     for container in client.containers.list():
         if "pyemr" in container.attrs["Config"]["Image"]:
@@ -191,13 +189,13 @@ def docker_containers_list():
 
 
 def stop_pyemr_containers():
-    """ """
+    """Stops all pyemr containers."""
     for c in docker_containers_list():
         c.stop()
 
 
-def is_check_docker_engine_responding(seconds=6):
-    """
+def is_check_docker_engine_responding(seconds):
+    """Checks if they docker engine is responding.
 
     Args:
       seconds: (Default value = 6)
@@ -206,7 +204,6 @@ def is_check_docker_engine_responding(seconds=6):
 
     """
     try:
-        seconds = 6
         output = check_output(
             ["docker", "container", "ls"],
             stderr=STDOUT,
@@ -220,9 +217,21 @@ def is_check_docker_engine_responding(seconds=6):
         return False
 
 
+def kill_docker_engine():
+    """Kills and tries to restart docker engine"""
+    pipe_cmd("killall Docker && open /Applications/Docker.app")
+
+
 def docker_engine_warning():
-    """ """
-    if not is_check_docker_engine_responding(30):
+    """Ckecks if docker engine is responding.
+    Asks the user if they want to try and restart it.
+
+    Args:
+
+    Returns:
+
+    """
+    if not is_check_docker_engine_responding(7):
         resp = cinput("Docker not responding. Restart docker engine?", "n")
         if resp in ["y", "Y", True, "yes", "YES", "Yes", "true", "True"]:
-            pipe_cmd("killall Docker && open /Applications/Docker.app")
+            kill_docker_engine()
