@@ -107,42 +107,7 @@ def wait_else_cancel(cluster_id, step_id, description="Waiting"):
 
 
 def get_cluster_states(state_pattern: str):
-    """Takes the state str pattern then returns the matching emr states.
-
-    Args:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-      state_pattern: str:
-
-    Returns:
-
-    """
+    """Takes the state str pattern then returns the matching emr states."""
     if state_pattern.strip() == "*":
         return ALL_CLUSTER_STATES
 
@@ -200,27 +165,7 @@ def get_clusters() -> dict:
 @lru_cache()
 def get_cluster_id(cluster_name: str) -> str:
     """Returns the id of a cluster from its name. If no exact name match is found then a lower case is used.
-
-    Args:
-      cluster_name: str
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-
+    
     Returns:
       str: The id for cluster with name <cluster_name>
 
@@ -307,31 +252,7 @@ def get_master_ec2_instance_id(cluster_name):
 
 
 def ssm_cluster(cluster_name: str):
-    """Opens an ssm session into the master node of the given cluster
-
-    Args:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-      cluster_name: str:
-
-    Returns:
-
-    """
+    """Opens an ssm session into the master node of the given cluster"""
     master_ec2_instanceid = get_master_ec2_instance_id(cluster_name)
     cprint(f'Running "aws ssm start-session --target {master_ec2_instanceid}"')
     os.system(f"aws ssm start-session --target {master_ec2_instanceid}")
@@ -481,71 +402,7 @@ def get_step_id(step_id: str, cluster_name: str, name_pattern: str, state: str):
       cluster_name: str:
       name_pattern: str:
       state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-      step_id: str:
-      cluster_name: str:
-      name_pattern: str:
-      state: str:
-
+      
     Returns:
 
     """
