@@ -2,9 +2,12 @@
 import sys
 
 
+print("sys.path", sys.path)
+print("sys.argv", sys.argv)
+
 if __name__ == "__main__":
     sys.path += sys.argv[1].split(",")
-    from pyemr.utils.poetry import set_spark_home
+    from pyemr.utils.config import set_spark_home
 
     set_spark_home()
     from pyemr.utils.mocking import launch_kernelapp
